@@ -5,6 +5,7 @@ from dataclasses import dataclass, is_dataclass
 from inspect import Parameter, signature
 from operator import attrgetter
 from pathlib import Path
+import re
 from typing import (
     Any,
     Callable,
@@ -15,6 +16,7 @@ from typing import (
     Tuple,
     Type,
     Union,
+    TypeVar,
     get_type_hints,
 )
 from ream.actors.interface import Actor
@@ -26,10 +28,11 @@ from loguru import logger
 
 from ream.actors.base import BaseActor
 from ream.helper import _logger_formatter, get_classpath
-from ream.params_helper import DataClassInstance
+from ream.params_helper import DataClassInstance, NoParams
 
 
 ActorEdge = BaseEdge
+A = TypeVar("A")
 
 
 class ActorNode(BaseNode):
@@ -70,7 +73,7 @@ class ActorGraph(RetworkXDiGraph[int, ActorNode, ActorEdge]):
     class ActorConstructor:
         graph: ActorGraph
         main: ActorNode
-        params_cls: Any
+        params_cls: list[type[DataClassInstance]]
         params_ns: list[str]
         node2param: Dict[Type, Tuple[int, int]]
         node2cls: Dict[Type, ActorNode]
@@ -133,6 +136,7 @@ class ActorGraph(RetworkXDiGraph[int, ActorNode, ActorEdge]):
         actor_cls: Union[Sequence[Type[BaseActor]], Mapping[str, Type[BaseActor]]],
         strict: bool = False,
         namespaces: Optional[Sequence[str]] = None,
+        auto_naming: bool = False,
     ) -> ActorGraph:
         """Automatically create an actor graph from list of actor classes.
 
@@ -147,6 +151,8 @@ class ActorGraph(RetworkXDiGraph[int, ActorNode, ActorEdge]):
             namespaces: List of namespaces to be used for actor parameter parser. If None, there is no namespace. Only works if actor_cls is a sequence. The
                 reason we need this is for some actors, we want to use a global namespace ""
 
+            auto_naming: whether to automatically generate a namespace for each actor class. Only works if actor_cls is a sequence and namespaces is None.
+                The namespace is generated by removing the suffix "Actor" from the actor class name.
         Returns:
             ActorGraph
         """
@@ -166,6 +172,16 @@ class ActorGraph(RetworkXDiGraph[int, ActorNode, ActorEdge]):
                         f"Auto graph construction cannot handle duplicated actor class. Found one: {cls}"
                     )
 
+                if namespaces is not None:
+                    namespace = namespaces[i]
+                elif auto_naming:
+                    clsname = cls.__qualname__
+                    if clsname.endswith("Actor"):
+                        clsname = clsname[: -len("Actor")]
+                    namespace = re.sub(r"(?<!^)(?=[A-Z])", "_", clsname).lower()
+                else:
+                    namespace = ""
+
                 namespace = namespaces[i] if namespaces is not None else ""
                 idmap[cls] = g.add_node(ActorNode.new(cls, namespace=namespace))
 
@@ -198,23 +214,36 @@ class ActorGraph(RetworkXDiGraph[int, ActorNode, ActorEdge]):
 
     def create_actor(
         self,
-        actor_class: Union[str, Type],
-        args: Optional[Sequence[str]] = None,
+        actor_class: Union[str, type[A]],
+        args: Optional[Union[Sequence[str], Sequence[DataClassInstance]]] = None,
         log_file: Optional[str] = None,
-    ):
+    ) -> A:
         """Create an actor from arguments passed through the command lines
 
         Args:
             actor_class: The class of the actor to run. If there are multiple actors
                 in the graph having the same name, it will throw an error.
-            args: The arguments to the . If not provided, it will use the arguments from sys.argv
+            args: The arguments to the actor and its dependencies. If not provided, it will use the arguments from sys.argv.
+                If it is a sequence of string, then it will be passed to the params parser. If it is a sequence of DataClassInstance,
+                then it will be passed directly to the actor's init function.
         """
         logger.debug("Determine the actor to run...")
         actor_node = self.get_actor_by_classname(actor_class)
         logger.debug("Initializing argument parser...")
         constructor = self.get_actor_constructor(actor_node)
-        parser = constructor.get_params_parser()
-        params = parser.parse_args(args)
+        if args is not None and len(args) > 0 and not isinstance(args[0], str):
+            # re-order the arguments to match the order of the param_cls.
+            # for this to work, we assume that the classes of parameters are unique
+            type2arg = {type(arg): arg for arg in args}
+            n_no_params = sum(1 for arg in args if isinstance(arg, NoParams))
+            if len(type2arg) != len(args) - (n_no_params - 1 if n_no_params > 1 else 0):
+                raise ValueError(
+                    "Cannot create actor from list of parameter instances because there are duplicated parameter classes (ream.params_helper.NoParams does not count)."
+                )
+            params = [type2arg[param_cls] for param_cls in constructor.params_cls]
+        else:
+            parser = constructor.get_params_parser()
+            params = parser.parse_args(args)
 
         logger.debug("Constructing the actor...")
         actor = constructor.create_actor(params)
