@@ -254,18 +254,14 @@ class ClsSerdeCache:
         ):
             for i, item in enumerate(items):
                 if item is not None:
-                    ifile = file.parent / (
-                        file.name + f"_{i}.{exts[i]}" if exts is not None else f"_{i}"
-                    )
+                    ifile = file / (f"_{i}.{exts[i]}" if exts is not None else f"_{i}")
                     item.save(ifile, *args)
             file.touch()
 
         def deser(file: Path, *args):
             output = []
             for i, cls in enumerate(classes):
-                ifile = file.parent / (
-                    file.name + f"_{i}.{exts[i]}" if exts is not None else f"_{i}"
-                )
+                ifile = file / (f"_{i}.{exts[i]}" if exts is not None else f"_{i}")
                 if ifile.exists():
                     output.append(cls.load(ifile, *args))
                 else:
@@ -444,7 +440,7 @@ class Cache:
                     with fs.acquire_write_lock(), cache_file.reserve_and_track() as fpath:
                         if log_serde_time:
                             with Timer().watch_and_report(
-                                f"serialize file {cache_file.relpath}",
+                                f"serialize file {cache_file._realdiskpath}",
                                 self.logger.debug,
                             ):
                                 ser(output, fpath)
@@ -453,7 +449,8 @@ class Cache:
                 else:
                     if log_serde_time:
                         with Timer().watch_and_report(
-                            f"deserialize file {cache_file.relpath}", self.logger.debug
+                            f"deserialize file {cache_file._realdiskpath}",
+                            self.logger.debug,
                         ):
                             output = deser(cache_file.get())
                     else:
@@ -562,7 +559,7 @@ class Cache:
                     with fs.acquire_write_lock(), cache_file.reserve_and_track() as fpath:
                         if log_serde_time:
                             with Timer().watch_and_report(
-                                f"serialize file {cache_file.relpath}",
+                                f"serialize file {cache_file._realdiskpath}",
                                 self.logger.debug,
                             ):
                                 ser(output, fpath, compression)
@@ -571,7 +568,8 @@ class Cache:
                 else:
                     if log_serde_time:
                         with Timer().watch_and_report(
-                            f"deserialize file {cache_file.relpath}", self.logger.debug
+                            f"deserialize file {cache_file._realdiskpath}",
+                            self.logger.debug,
                         ):
                             output = deser(cache_file.get(), compression)
                     else:
@@ -866,12 +864,19 @@ class HasWorkingFsTrait(Protocol):
 
 
 class Cacheable:
-    """A class that implement HasWorkingFSTrait so it can be used with @Cache.file decorator."""
+    """A class that implement HasWorkingFSTrait so it can be used with @Cache.file decorator.
 
-    def __init__(self, workdir: Path):
-        self.workdir = FS(workdir)
+    Args:
+        workdir: directory to store cached files.
+        disable: set to True to disable caching. The wrapper method needs to use this flag to be effective!
+    """
+
+    def __init__(self, workdir: Union[FS, Path], disable: bool = False):
+        self.workdir = FS(workdir) if isinstance(workdir, Path) else workdir
         self.logger = logger.bind(name=self.__class__.__name__)
 
+        self.disable = disable
+
     def get_working_fs(self) -> FS:
         return self.workdir
 
