@@ -7,7 +7,6 @@ import struct
 from dataclasses import dataclass, fields, is_dataclass
 from pathlib import Path, PosixPath, WindowsPath
 from typing import (
-    IO,
     BinaryIO,
     Callable,
     Generic,
@@ -22,7 +21,10 @@ from typing import (
     get_origin,
     get_type_hints,
 )
+from typing_extensions import Self
 from copy import deepcopy
+from nptyping import NDArray, Shape
+from nptyping.typing_ import Float64, Number
 import numpy as np
 import orjson
 import pyarrow as pa
@@ -178,11 +180,14 @@ class NumpyDataModel:
         metadata: NumpyDataModelMetadata = self._metadata  # type: ignore
         return len(getattr(self, metadata.array_props[0]))
 
-    def shallow_clone(self):
+    def shallow_clone(self) -> Self:
         return self.__class__(*(getattr(self, name) for name in self.__slots__))
 
     def replace(self, field: str, value: np.ndarray):
-        assert getattr(self, field).shape == value.shape
+        assert getattr(self, field).shape == value.shape, (
+            getattr(self, field).shape,
+            value.shape,
+        )
         newobj = self.shallow_clone()
         setattr(newobj, field, value)
         return newobj
@@ -873,6 +878,17 @@ class NumpyDataModelHelper:
         return index
 
 
+class SingleNumpyArray(NumpyDataModel):
+    __slots__ = ["value"]
+
+    value: NDArray[Shape["*"], Number]
+
+    def __init__(self, value: NDArray[Shape["*"], Number]):
+        self.value = value
+
+
+SingleNumpyArray.init()
+
 # dir = VirtualDir("/tmp", filetrack=FileTrack())
 # print(dir.name2file, dir.filetrack)
 # dir / "test.h5"
